@@ -73,12 +73,6 @@ typedef struct
          int     from_network;  /* true if the player is located on */
                                 /* a remote machine                 */
         } CURSOR;
-/*
-int ACTIVE_FIGHTER[NB_TEAMS];
-int TEAM_COLOR_FIRST_ENTRY[NB_TEAMS];
-
-ces champs ont ete bascules dans la structure curseur
-*/
 
 /*==================================================================*/
 /* variables globales                                               */
