@@ -416,7 +416,7 @@ int load_custom (void)
 /*------------------------------------------------------------------*/
 void order_map (void)
 {
- char placed[RAW_MAP_MAX_NUMBER];
+  /* char placed[RAW_MAP_MAX_NUMBER];
  int i,j,n=0,size,low_limit;
  int *data;
 
@@ -441,6 +441,38 @@ void order_map (void)
           }
       placed[n]=1;
       RAW_MAP_ORDERED[i]=RAW_MAP[n];
-     }
+      }*/
+
+  int incorrect_order=1;
+  int i;
+
+
+  char name1[LW_MAP_READABLE_NAME_SIZE+1];
+  char name2[LW_MAP_READABLE_NAME_SIZE+1];
+  void *temp;
+
+  for (i=0;i<RAW_MAP_NUMBER;++i)
+    {
+      RAW_MAP_ORDERED[i]=RAW_MAP[i];
+    }
+
+  while (incorrect_order)
+    {
+      incorrect_order=0;
+
+      for (i=0;i<RAW_MAP_NUMBER-1;++i)
+	{
+	  strcpy(name1,get_map_readable_name(i));
+	  strcpy(name2,get_map_readable_name(i+1));
+	  if (strcmp(name1,name2)>0)
+	    {
+	      incorrect_order=1;
+
+	      temp=RAW_MAP_ORDERED[i];
+	      RAW_MAP_ORDERED[i]=RAW_MAP_ORDERED[i+1];
+	      RAW_MAP_ORDERED[i+1]=temp;
+	    }
+	}
+    }
 }
 
