@@ -44,6 +44,21 @@
 /* variables globales                                               */
 /*==================================================================*/
 
+#ifdef ALLEGRO_DOS
+int GFX_MODE_W[5]={320,360,640,800,1024};
+int GFX_MODE_H[5]={240,240,480,600,768};
+#endif
+
+#ifdef ALLEGRO_WINDOWS
+int GFX_MODE_W[5]={320,512,640,800,1024};
+int GFX_MODE_H[5]={240,384,480,600,768};
+#endif
+
+#ifdef ALLEGRO_UNIX
+int GFX_MODE_W[5]={320,512,640,800,1024};
+int GFX_MODE_H[5]={240,384,480,600,768};
+#endif
+
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
@@ -63,35 +78,29 @@ int set_resolution (int res, int flip)
  int num_try;
  int nb_try;
 
- #ifdef ALLEGRO_DOS
-	static int GFX_MODE_TYPE[]={GFX_MODEX,
-				GFX_MODEX,
-				GFX_AUTODETECT,
-				GFX_AUTODETECT,
-				GFX_AUTODETECT};
-	static int GFX_MODE_W[]={320,360,640,800,1024};
-	static int GFX_MODE_H[]={240,240,480,600,768};
- #endif
+#ifdef ALLEGRO_DOS
+ static int GFX_MODE_TYPE[]={GFX_MODEX,
+			     GFX_MODEX,
+			     GFX_AUTODETECT,
+			     GFX_AUTODETECT,
+			     GFX_AUTODETECT};
+#endif
 
- #ifdef ALLEGRO_WINDOWS
+#ifdef ALLEGRO_WINDOWS
 	static int GFX_MODE_TYPE[]={GFX_AUTODETECT,
 				GFX_AUTODETECT,
 				GFX_AUTODETECT,
 				GFX_AUTODETECT,
 				GFX_AUTODETECT};
-	static int GFX_MODE_W[]={320,512,640,800,1024};
-	static int GFX_MODE_H[]={240,384,480,600,768};
- #endif
+#endif
 
- #ifdef ALLEGRO_UNIX
+#ifdef ALLEGRO_UNIX
 	static int GFX_MODE_TYPE[]={GFX_AUTODETECT,
 				GFX_AUTODETECT,
 				GFX_AUTODETECT,
 				GFX_AUTODETECT,
 				GFX_AUTODETECT};
-	static int GFX_MODE_W[]={320,512,640,800,1024};
-	static int GFX_MODE_H[]={240,384,480,600,768};
- #endif
+#endif
 
  nb_try=0;
  while (nb_try<5 && ret){
