@@ -114,7 +114,8 @@ static void retrieve_choose_level_xy (int *x1,
                                       int *y2,
                                       int *y3,
                                       int *y4,
-                                      int *y5)
+                                      int *y5,
+				      int *y6)
 {
    (*x1)= (MENU_VIRTUAL_W -MENU_W_LEVEL*2
                           -MENU_H_LEVEL*2
@@ -127,25 +128,26 @@ static void retrieve_choose_level_xy (int *x1,
    (*x5)=(*x4)+MENU_W_SAMPLE+MENU_W_SPACE;
    (*x6)=(*x5)+MENU_H_LEVEL+MENU_H_SPACE;
 
-   (*y1)= (MENU_VIRTUAL_H -MENU_H_LEVEL
-                          -MENU_H_SPACE
+   (*y1)= (MENU_VIRTUAL_H -MENU_H_LEVEL*2
+                          -MENU_H_SPACE*2
                           -MENU_H_SAMPLE)/2;
    (*y2)=(*y1)+MENU_H_LEVEL+MENU_H_SPACE;
    (*y3)=(*y1)+MENU_W_LEVEL+MENU_H_SPACE;
    (*y4)=(*y1)+MENU_H_SAMPLE-MENU_H_LEVEL;
    (*y5)=(*y4)+MENU_H_LEVEL+MENU_H_SPACE;
+   (*y6)=(*y5)+MENU_H_LEVEL+MENU_H_SPACE;
 }
 
 /*------------------------------------------------------------------*/
 static void display_chosen_level (void)
 {
- int  x1,x2,x3,x4,x5,x6,y1,y2,y3,y4,y5;
+ int  x1,x2,x3,x4,x5,x6,y1,y2,y3,y4,y5,y6;
  int  sample_x,sample_y,sample_w,sample_h;
  int  max_w,max_h,bmp_w,bmp_h;
  BITMAP *pour_voir;
 
  retrieve_choose_level_xy (&x1,&x2,&x3,&x4,&x5,&x6,
-                             &y1,&y2,&y3,&y4,&y5);
+                             &y1,&y2,&y3,&y4,&y5,&y6);
 
  rectfill (screen, menu_real_x(x4),
                    menu_real_y(y1),
@@ -219,6 +221,8 @@ static void display_chosen_level (void)
 /*------------------------------------------------------------------*/
 static void update_choose_map (DIALOG *d)
 {
+  static char res_buffer[30];
+  int res_w,res_h;
 
  sprintf (d[13].dp,"%d",CONFIG_LEVEL_MAP+1);
  my_edit_proc (MSG_DRAW, d+13, 0);
@@ -252,6 +256,14 @@ static void update_choose_map (DIALOG *d)
  if (d[6].d2>d[6].d1)
    d[6].d2=0;
  my_slider_proc (MSG_DRAW,d+6,0);
+
+ get_map_res(CONFIG_LEVEL_MAP,&res_w,&res_h);
+ sprintf(res_buffer,"%dx%d",res_w,res_h);
+ d[16].dp=res_buffer;
+ my_textbox_proc (MSG_DRAW,d+16,0);
+ 
+ d[17].dp=get_map_readable_name(CONFIG_LEVEL_MAP);
+ my_textbox_proc (MSG_DRAW,d+17,0);
  
  display_chosen_level ();
 }
@@ -306,10 +318,10 @@ static void box_for_choose_map (void)
  DIALOG_PLAYER *dp;
  int i;
  int x1,x2,x3,x4,x5,x6;
- int y1,y2,y3,y4,y5;
+ int y1,y2,y3,y4,y5,y6;
 
  retrieve_choose_level_xy (&x1,&x2,&x3,&x4,&x5,&x6,
-                           &y1,&y2,&y3,&y4,&y5);
+                           &y1,&y2,&y3,&y4,&y5,&y6);
 
  d[0].x=x4;
  d[0].y=y1;
@@ -367,8 +379,8 @@ int choose_map (void)
    int retour=0,choix=MENU_QUICK_BACK;
    int i;
    int x1,x2,x3,x4,x5,x6;
-   int y1,y2,y3,y4,y5;
-   DIALOG d[273];
+   int y1,y2,y3,y4,y5,y6;
+   DIALOG d[275];
    char buf1[BUFFER_EDIT_NUMBER +1];
    char buf2[BUFFER_EDIT_NUMBER +1];
    char buf3[BUFFER_EDIT_NUMBER +1];
@@ -380,7 +392,7 @@ int choose_map (void)
    quick_buttons (d);
 
    retrieve_choose_level_xy (&x1,&x2,&x3,&x4,&x5,&x6,
-                             &y1,&y2,&y3,&y4,&y5);
+                             &y1,&y2,&y3,&y4,&y5,&y6);
 
    d[4].proc=d[5].proc=d[6].proc=my_slider_proc;
    d[4].dp=d[5].dp=d[6].dp=NULL;
@@ -390,9 +402,9 @@ int choose_map (void)
    d[6].dp2=slider_bg;
    d[4].dp3=d[5].dp3=d[6].dp3=d;
    d[4].flags=d[5].flags=d[6].flags=0;
-#ifdef ALLEGRO_WINDOWS
-   d[4].flags=d[5].flags=d[6].flags=D_HIDDEN;
-#endif
+   //#ifdef ALLEGRO_WINDOWS
+   //d[4].flags=d[5].flags=d[6].flags=D_HIDDEN;
+   //#endif
    d[4].d1=RAW_MAP_NUMBER-1;
    d[5].d1=d[6].d1=RAW_TEXTURE_NUMBER-1;
    d[4].d2=CONFIG_LEVEL_MAP;
@@ -439,25 +451,42 @@ int choose_map (void)
    d[13].y=y5;
    d[14].y=d[15].y=y4;
 
-  for (i=4; i<16; ++i)
+   d[16].proc=my_textbox_proc;
+   d[16].x=x1;
+   d[16].y=y6;
+   d[16].w=x4-x1-MENU_W_SPACE;
+   d[16].h=MENU_H_LEVEL;
+   d[16].flags=0;
+   d[16].dp="";
+
+   d[17].proc=my_textbox_proc;
+   d[17].x=x4;
+   d[17].y=y6;
+   d[17].w=x6-x4+MENU_W_LEVEL;
+   d[17].h=MENU_H_LEVEL;
+   d[17].flags=0;
+   d[17].dp="";
+
+  for (i=4; i<18; ++i)
       {
        color_one_dialog (d+i);
        menu_real_coord (d+i);
       }
 
-   palette_128 (d+16,
+   palette_128 (d+18,
                 menu_real_x (x1),
                 menu_real_y (y3),
                 menu_real_x (MENU_W_LEVEL),
                 menu_real_y (y4-y3-MENU_H_SPACE));
-   palette_128 (d+144,
+   palette_128 (d+146,
                 menu_real_x (x6),
                 menu_real_y (y3),
                 menu_real_x (MENU_W_LEVEL),
                 menu_real_y (y4-y3-MENU_H_SPACE));
 
    box_for_choose_map ();
-   d[272].proc=NULL;
+
+   d[274].proc=NULL;
 
    update_choose_map (d);
 
@@ -548,14 +577,14 @@ int choose_map (void)
                   break;
 
              default:
-                  if (choix>=16 && choix <144)
+                  if (choix>=18 && choix <146)
                      {
-                      CONFIG_LEVEL_FG=choix-16;
+                      CONFIG_LEVEL_FG=choix-18;
                       update_choose_map (d);
                      }
-                  if (choix>=144 && choix <272)
+                  if (choix>=146 && choix <274)
                      {
-                      CONFIG_LEVEL_BG=choix-144;
+                      CONFIG_LEVEL_BG=choix-146;
                       update_choose_map (d);
                      }
             }
