@@ -39,6 +39,12 @@
 
 #include <allegro.h>
 
+/*==================================================================*/
+/* constants                                                        */
+/*==================================================================*/
+
+#define LW_MAP_READABLE_NAME_SIZE 32
+
 /*==================================================================*/
 /* fonctions globales                                               */
 /*==================================================================*/
@@ -46,5 +52,7 @@
 void *archive_raw_map (const char *filename);
 BITMAP *create_bicolor_map (int, int, int);
 BITMAP *create_textured_map (int, int, int);
+char *get_map_readable_name (int num);
+void get_map_res (int num,int *w,int *h);
 
 #endif
