@@ -225,3 +225,15 @@ int lw_netkey_recv(int sock,LW_NETKEY *netkey)
   return result;
 }
 
+/*------------------------------------------------------------------*/
+/*
+ * Returns true if at leat "num" keys are available on the socket
+ */
+int lw_netkey_peek(int sock,int num)
+{
+  int result;
+
+  result=lw_sock_peek(sock,num*LW_NETKEY_SERIALIZED_SIZE);
+
+  return result;
+}
