@@ -47,6 +47,7 @@
 #include "sound.h"
 #include "rules.h"
 #include "volume.h"
+#include "speeds.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -59,21 +60,22 @@
 /*------------------------------------------------------------------*/
 int options (void)
 {
- DIALOG d[9];
+ DIALOG d[10];
   int i,choix=4,retour=0;
 
   while (retour==0)
          {
-          for (i=0; i<3; ++i)
-              standard_button (d+i+4,0,i,1,5);
-          standard_button (d+7,0,4,1,5);
+          for (i=0; i<4; ++i)
+              standard_button (d+i+4,0,i,1,6);
+          standard_button (d+8,0,5,1,6);
 
           quick_buttons(d);
           d[4].dp="Graphics";
           d[5].dp="Sound";
           d[6].dp="Rules";
-          d[7].dp="Default";
-          d[8].proc=0;
+	  d[7].dp="Speeds";
+          d[8].dp="Default";
+          d[9].proc=0;
 
           choix=my_do_dialog (d,choix);
           switch (choix)
@@ -105,6 +107,9 @@ int options (void)
                   retour=rules_options ();
                   break;
              case 7:
+                  retour=speeds_options ();
+                  break;
+             case 8:
 		  load_default_options ();
                   retour=0;
                   break;
