@@ -47,6 +47,8 @@
 #include "play.h"
 #include "score.h"
 #include "sound.h"
+#include "sock2gen.h"
+#include "keyexch.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -158,6 +160,11 @@ int play_sequence (void)
       * let's be clean 8-)
       */
      free_game_memory();
+     
+     /*
+      * we close the network socket abruptly
+      */
+     lw_sock_close(LW_KEYEXCH_SOCK);
 
      /*
       * we turn the volume down
@@ -187,6 +194,12 @@ int play_sequence (void)
       * amount of data reserved at startup (command line parameter)
       */
      free_game_memory();
+
+     /*
+      * we close the network socket abruptly
+      */
+     lw_sock_close(LW_KEYEXCH_SOCK);
+
      error_not_enough_big_data ();
     }
   }
