@@ -84,49 +84,46 @@ static int slider_time (void *dp3, int d2)
 int rules_options (void)
 {
   int *temp;
-  DIALOG d[12];
+  DIALOG d[10];
   int i,choix=4,retour=0;
-  static int y_pos[4]={0,1,2,4};
+  static int y_pos[3]={0,1,3};
   char time_str[14];
   
   strcpy(time_str,"Time    00:00");
 
-  for (i=0; i<3; ++i)
+  for (i=0; i<2; ++i)
       {
-       standard_button (d+i+4,0,y_pos[i],2,5);
+       standard_button (d+i+4,0,y_pos[i],2,4);
        d[i+4].proc=my_textbox_proc;
       }
-  for (i=0; i<3; ++i)
+  for (i=0; i<2; ++i)
       {
-       standard_button (d+i+7,1,y_pos[i],2,5);
-       d[i+7].proc=my_slider_proc;
+       standard_button (d+i+6,1,y_pos[i],2,4);
+       d[i+6].proc=my_slider_proc;
       }
 
-  standard_button (d+10,0,4,1,5);
-  d[10].dp="Advanced";
+  standard_button (d+8,0,3,1,4);
+  d[8].dp="Advanced";
 
   quick_buttons(d);
-  d[4].dp="Cursor speed";
-  d[5].dp="Army size";
-  d[6].dp=time_str;
-  d[7].d1=2;
-  d[8].d1=32;
-  d[9].d1=16;
-  d[7].dp3=&CONFIG_CURSOR_INCREASE_SPEED;
-  d[8].dp3=&CONFIG_FIGHTER_NUMBER;
-  d[9].dp3=&CONFIG_GAME_TIME;
-  for (i=7;i<10;++i)
+  d[4].dp="Army size";
+  d[5].dp=time_str;
+  d[6].d1=32;
+  d[7].d1=16;
+  d[6].dp3=&CONFIG_FIGHTER_NUMBER;
+  d[7].dp3=&CONFIG_GAME_TIME;
+  for (i=6;i<8;++i)
       {
        d[i].dp=NULL;
        d[i].dp2=slider_int;
        temp=d[i].dp3;
        d[i].d2=*temp;
       }
-  d[9].dp2=slider_time;
-  d[9].dp3=d+6;
-  write_time_setting (d+6);
+  d[7].dp2=slider_time;
+  d[7].dp3=d+5;
+  write_time_setting (d+5);
  
-  d[11].proc=0;
+  d[9].proc=0;
 
   while (retour==0)
         {
@@ -147,7 +144,7 @@ int rules_options (void)
              case MENU_QUICK_HELP:
                   retour=display_help (HELP_TEXT_RULES);
                   break;
-             case 10 :
+             case 8 :
                   retour=advanced_options();
                   break;
              }
