@@ -51,12 +51,15 @@
 /*==================================================================*/
 
 #define LW_SERVER_IDENT_LAG "lag"
+#define LW_SERVER_IDENT_PORT "port"
 
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
 
 static int get_nb_teams();
+static int get_lag();
+static int get_port();
 
 /*------------------------------------------------------------------*/
 /*
@@ -118,6 +121,26 @@ static int get_lag()
   return result;
 }
 
+/*------------------------------------------------------------------*/
+/*
+ * Returns the port which should be used to communicate with clients
+ */
+static int get_port()
+{
+  int result=LW_SERVER_DEFAULT_PORT;
+
+  if (exist_argument(LW_SERVER_IDENT_PORT))
+    {
+      result=get_argument_int(LW_SERVER_IDENT_PORT);
+      if (result<=0)
+	{
+	  result=LW_SERVER_DEFAULT_PORT;
+	}
+    }
+
+  return result;
+}
+
 /*------------------------------------------------------------------*/
 /*
  * Main function, launches the server.
@@ -150,7 +173,7 @@ int main(int argc, char **argv)
 	    {
 	      if (lw_srvcont_wait_teams(&cont, 
 					nb_teams, 
-					LW_SERVER_DEFAULT_PORT))
+					get_port()))
 		{
 		  if (lw_srvcont_tell_who(&cont))
 		    {
