@@ -51,6 +51,7 @@
 #include <time.h>
 #include <string.h>
 #include <ctype.h>
+#include <errno.h>
 
 #include "sockgen.h"
 #include "log.h"
@@ -64,7 +65,8 @@
 #define LW_SOCK_SEND_SEC                  8
 #define LW_SOCK_SEND_USEC                 0 
 
-#define LW_SOCK_SEND_BUFFER_SIZE        200
+#define LW_SOCK_SEND_BUFFER_SIZE        100
+#define LW_SOCK_RECV_BUFFER_SIZE        200
 
 /*==================================================================*/
 /* macros                                                           */
@@ -182,10 +184,19 @@ int lw_sock_send_str_ex(int sock, char *str)
       FD_SET(sock,&write);
       tv.tv_sec=LW_SOCK_SEND_SEC;
       tv.tv_usec=LW_SOCK_SEND_USEC;
+
+      errno=0;
       res=select(sock+1,NULL,&write,NULL,&tv);
 
-      if (res>0)
+      switch (res)
 	{
+	case -1:
+	  if (errno!=EINTR)
+	    {
+	      result=0;
+	    }
+	  break;
+	case 1:
 	  if (FD_ISSET(sock,&write))
 	    {
 	      sent=send(sock,buffer+total_sent,len-total_sent,0);
@@ -198,9 +209,8 @@ int lw_sock_send_str_ex(int sock, char *str)
 		  result=0;
 		}
 	    }
-	}
-      if (res<0)
-	{
+	  break;
+	default:
 	  result=0;
 	}
     }
@@ -265,13 +275,19 @@ int lw_sock_recv_str_ex(int sock, char *str)
       FD_SET(sock,&read);
       tv.tv_sec=LW_SOCK_RECV_SEC;
       tv.tv_usec=LW_SOCK_RECV_USEC;
+
+      errno=0;
       res=select(sock+1,&read,NULL,NULL,&tv);
-      if (res<=0)
-	{
-	  result=0;
-	}
-      else
+
+      switch (res)
 	{
+	case -1:
+	  if (errno!=EINTR)
+	    {
+	      result=0;
+	    }
+	  break;
+	case 1:
 	  /*
 	   * We check that the event we just received concerns the socket
 	   * we are polling. If the event is not for us, let's consider
@@ -350,6 +366,9 @@ int lw_sock_recv_str_ex(int sock, char *str)
 		  result=1;
 		}
 	    }
+	  break;
+	default:
+	  result=0;
 	}
     }
 
@@ -399,15 +418,25 @@ int lw_sock_send_buffer_ex(int sock, char *buffer,int len)
 	  FD_SET(sock,&write);
 	  tv.tv_sec=LW_SOCK_SEND_SEC;
 	  tv.tv_usec=LW_SOCK_SEND_USEC;
+
+	  errno=0;
 	  res=select(sock+1,NULL,&write,NULL,&tv);
 	  
-	  if (res>0)
+	  switch (res)
 	    {
+	    case -1:
+	      if (errno!=EINTR)
+		{
+		  result=0;
+		}
+	      break;
+	    case 1:
 	      if (FD_ISSET(sock,&write))
 		{
 		  sent=send(sock,
 			    buffer+total_sent,
-			    MIN(len-total_sent,LW_SOCK_SEND_BUFFER_SIZE),
+			    MIN(len-total_sent,
+				LW_SOCK_SEND_BUFFER_SIZE),
 			    0);
 		  if (sent>0 && sent<=len-total_sent)
 		    {
@@ -418,9 +447,8 @@ int lw_sock_send_buffer_ex(int sock, char *buffer,int len)
 		      result=0;
 		    }
 		}
-	    }
-	  if (res<0)
-	    {
+	      break;
+	    default:
 	      result=0;
 	    }
 	}
@@ -468,36 +496,55 @@ int lw_sock_send_buffer_ex(int sock, char *buffer,int len)
  */
 int lw_sock_recv_buffer_ex(int sock, char *buffer,int len)
 {
-  int result=0;
+  int result=1;
   char trace[LW_SOCK_MESSAGE_SIZE];
   int res;
   fd_set read;
   struct timeval tv;
+  int total_received;
+  int received;
 
   if (len<=LW_SOCK_MESSAGE_SIZE-1)
     {
-      FD_ZERO(&read);
-      FD_SET(sock,&read);
-      tv.tv_sec=LW_SOCK_RECV_SEC;
-      tv.tv_usec=LW_SOCK_RECV_USEC;
-      res=select(sock+1,&read,NULL,NULL,&tv);
-      if (res>0)
+      total_received=0;
+      while (total_received<len && result)
 	{
-	  if (FD_ISSET(sock,&read))
+	  FD_ZERO(&read);
+	  FD_SET(sock,&read);
+	  tv.tv_sec=LW_SOCK_RECV_SEC;
+	  tv.tv_usec=LW_SOCK_RECV_USEC;
+
+	  errno=0;
+	  res=select(sock+1,&read,NULL,NULL,&tv);
+
+	  switch (res)
 	    {
-	      /* 
-	       * First we test if there's enough data available
-	       */
-	      if (recv(sock,buffer,len,MSG_PEEK)==len)
+	    case -1:
+	      if (errno!=EINTR)
 		{
-		  /*
-		   * Now we retrieve the data for good
-		   */
-		  if (recv(sock,buffer,len,0)==len)
+		  result=0;
+		}
+	      break;
+	    case 1:
+	      if (FD_ISSET(sock,&read))
+		{
+		  received=recv(sock,
+				buffer+total_received,
+				MIN(len-total_received,
+				    LW_SOCK_RECV_BUFFER_SIZE),
+				0);
+		  if (received>0 && received<=len-total_received)
 		    {
-		      result=1;
+		      total_received+=received;
+		    }
+		  else
+		    {
+		      result=0;
 		    }
 		}
+	      break;
+	    default:
+	      result=0;
 	    }
 	}
       
