@@ -799,11 +799,6 @@ int lw_srvchan_final_ok(LW_SRVCHAN *chan)
 {
   int result=0;
 
-  log_print_str("Start \"");
-  log_print_str(chan->nickname);
-  log_print_str("\"");
-  log_println();
-
   if (lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_OK))
     {
       result=1;
@@ -894,6 +889,9 @@ int lw_srvchan_recv_keys(LW_SRVCHAN *chan, LW_NETKEY *netkey)
 	}
     }
 
+  netkey->cmd=chan_netkey.cmd;
+  netkey->arg=chan_netkey.arg;
+
   return result;
 }
 
@@ -920,9 +918,11 @@ int lw_srvchan_send_keys(LW_SRVCHAN *chan, LW_NETKEY *netkey)
 	}
     }
 
+  chan_netkey.cmd=netkey->cmd;
+  chan_netkey.arg=netkey->arg;
+
   result=lw_netkey_send(chan->sock,&chan_netkey);
 
   return result;
 }
 
-
