@@ -36,7 +36,6 @@
 
 #include <stdlib.h>
 #include <sys/types.h>
-#include <time.h>
 
 #include "srvcont.h"
 #include "srvchan.h"
@@ -44,6 +43,7 @@
 #include "log.h"
 #include "server.h"
 #include "netkey.h"
+#include "srvtime.h"
 
 /*==================================================================*/
 /* constants                                                        */
@@ -381,7 +381,7 @@ int lw_srvcont_replicate_keys(LW_SRVCONT *cont,int lag)
     }
   else
     {
-      start=time(NULL);
+      start=lw_srvtime_seconds();
 
       while (cont->nb_chans>0)
 	{
@@ -525,8 +525,8 @@ int lw_srvcont_replicate_keys(LW_SRVCONT *cont,int lag)
 	  last_rounds++;
 	  average_lag+=lag;
 
-	  end=time(NULL);
-	  elapsed = difftime(end,start);
+	  end=lw_srvtime_seconds();
+	  elapsed = end-start;
 
 	  if (((int) elapsed)>LW_SRVCONT_DISPLAY_STATE_DELAY)
 	    {
