@@ -57,6 +57,7 @@ BITMAP *BITMAP_SRC=NULL;
 BITMAP *BITMAP_DST=NULL;
 signed char  BUFFER[1048576];
 int   DST_X,DST_Y,DST_W,DST_H,DST_SIZE,BG_SIZE;
+char READABLE_NAME[32];
 
 /*=================================================================*/
 /* fonctions                                                       */
@@ -258,12 +259,68 @@ void convert_to_buffer (void)
  DST_SIZE=pos_dst;
 }
 
+/*-----------------------------------------------------------------*/
+void change_ext_to_txt (char *str)
+{
+  char *ext;
+
+  ext=strchr (str, '.');
+  ext[1]='t';
+  ext[2]='x';
+  ext[3]='t';
+}
+
+/*-----------------------------------------------------------------*/
+void update_readable_name(char *str)
+{
+  FILE *f;
+  char *search;
+
+  memset(READABLE_NAME,0,sizeof(READABLE_NAME));
+
+  f=fopen(str,"r");
+  if (f!=NULL)
+    {
+      /*
+       * If there's a corresponding .txt file, we open it and interpret
+       * it as the name of the map
+       */
+      fread(READABLE_NAME,sizeof(READABLE_NAME),1,f);
+      fclose(f);
+      /*
+       * Now we get rid of all the lines following the first one
+       */
+      search=strchr(READABLE_NAME,10);
+      if (search)
+	{
+	  (*search)=0;
+	}
+      search=strchr(READABLE_NAME,13);
+      if (search)
+	{
+	  (*search)=0;
+	}
+    }
+  else
+    {
+      /*
+       * No .txt file we just use the file name
+       */
+      strncpy(READABLE_NAME,str,sizeof(READABLE_NAME));
+      search=strchr(READABLE_NAME,'.');
+      if (search)
+	{
+	  (*search)='\0';
+	}
+    }
+}
+
 /*-----------------------------------------------------------------*/
 /* on ecrit sur le disque                                          */
 /*-----------------------------------------------------------------*/
 
 /*-----------------------------------------------------------------*/
-void change_ext (char *str)
+void change_ext_to_map (char *str)
 {
   char *ext;
 
@@ -292,6 +349,7 @@ void write_to_disk (char *str)
     fwrite (&BG_SIZE,4,1,f);
     fwrite (&w,2,1,f);
     fwrite (&h,2,1,f);
+    fwrite (READABLE_NAME,sizeof(READABLE_NAME),1,f);
     fwrite (BUFFER,DST_SIZE,1,f);
     fclose (f);
  }
@@ -323,7 +381,11 @@ int main (int argc, char **argv)
  ARGC=argc;
  ARGV=argv;
 
+#ifdef ALLEGRO_UNIX
+ install_allegro(SYSTEM_NONE, &errno, atexit);
+#else
  allegro_init ();
+#endif
 
  if (read_command_line ())
     {
@@ -332,9 +394,12 @@ int main (int argc, char **argv)
           if (load_file (FILENAMES [i]))
              {
               get_range ();
-              write_with_new_size(FILENAMES [i]);
+	      if (BITMAP_SRC->w!=BITMAP_DST->w || BITMAP_SRC->h!=BITMAP_DST->h)
+              	  write_with_new_size(FILENAMES [i]);
               convert_to_buffer ();
-              change_ext (FILENAMES [i]);
+              change_ext_to_txt (FILENAMES [i]);
+	      update_readable_name(FILENAMES [i]);
+              change_ext_to_map (FILENAMES [i]);
               write_to_disk (FILENAMES [i]);
               }
         }
